==> opennms-web-api-24.0.0-20181110.071506-24-sources.jar: org/opennms/web/utils/ResponseUtils.java <==
/*******************************************************************************
 * This file is part of OpenNMS(R).
 *
 * Copyright (C) 2018-2018 The OpenNMS Group, Inc.
 * OpenNMS(R) is Copyright (C) 1999-2018 The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is a registered trademark of The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published
 * by the Free Software Foundation, either version 3 of the License,
 * or (at your option) any later version.
 *
 * OpenNMS(R) is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with OpenNMS(R).  If not, see:
 *      http://www.gnu.org/licenses/
 *
 * For more information contact:
 *     OpenNMS(R) Licensing <license@opennms.org>
 *     http://www.opennms.org/
 *     http://www.opennms.com/
 *******************************************************************************/

package org.opennms.web.utils;

import java.util.List;

import javax.ws.rs.core.Response;

public abstract class ResponseUtils {
    private ResponseUtils() {}

    public static <T> Response createResponse(List<T> entities, long offset, long totalCount) {
        if (entities == null || entities.isEmpty()) {
            return Response.noContent().build();
        }
        return Response.ok(entities).header("Content-Range", String.format("items %d-%d/%d", offset, offset + entities.size() - 1, totalCount)).build();
    }

}

==> opennms-web-api-31.0.8-sources.jar: org/opennms/web/utils/ResponseUtils.java <==
/*******************************************************************************
 * This file is part of OpenNMS(R).
 *
 * Copyright (C) 2018-2018 The OpenNMS Group, Inc.
 * OpenNMS(R) is Copyright (C) 1999-2018 The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is a registered trademark of The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published
 * by the Free Software Foundation, either version 3 of the License,
 * or (at your option) any later version.
 *
 * OpenNMS(R) is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with OpenNMS(R).  If not, see:
 *      http://www.gnu.org/licenses/
 *
 * For more information contact:
 *     OpenNMS(R) Licensing <license@opennms.org>
 *     http://www.opennms.org/
 *     http://www.opennms.com/
 *******************************************************************************/

package org.opennms.web.utils;

import java.util.List;

import javax.ws.rs.core.Response;

public abstract class ResponseUtils {
    private ResponseUtils() {}

    public static <T> Response createResponse(List<T> entities, long offset, long totalCount) {
        if (entities == null || entities.isEmpty()) {
            return Response.noContent().build();
        }
        final String contentRangeHeader = getContentRange(entities.size(), offset, totalCount);
        return Response.ok(entities).header("Content-Range", contentRangeHeader).build();
    }

    public static String getContentRange(long itemCount, long offset, long totalCount) {
        return String.format("items %d-%d/%d", offset, offset + itemCount - 1, totalCount);
    }

}
